import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { FormGroup, FormBuilder } from '@angular/forms';
import { ProjectService } from 'src/app/services/project.service';
import { SingleProjectConfig } from 'src/app/models/single-project-config';

@Component({
  selector: 'app-delete-project',
  templateUrl: './delete-project.component.html',
  styleUrls: ['./delete-project.component.css']
})
export class DeleteProjectComponent implements OnInit {

  actualProject: number;
  actualProjectConfig: SingleProjectConfig;
  isProjectLoading: boolean;
  isDeleteLoading: boolean;

  public formGroup: FormGroup;
  
  constructor(private _fb: FormBuilder, private route: ActivatedRoute, private router: Router, private projectService: ProjectService) {
    this.formGroup = this._fb.group({
      delete: [''],
    });
    
    this.route.params.subscribe(params =>
      this.actualProject = params['projectId']
    )
  }

  async ngOnInit() {
    await this.loadProject();
  }

  async loadProject() {
    this.isProjectLoading = true;
    try {
      let result = await this.projectService.getProject(this.actualProject);
      this.actualProjectConfig = result;
    } finally {
      this.isProjectLoading = false;
    }
  }

  async deleteProject() {
    this.isDeleteLoading = true;
    try {
      let result = await this.projectService.deleteProject(this.actualProject);
      this.router.navigateByUrl("/");
    } finally {
      this.isDeleteLoading = false;
    }
  }
}
