import { Component, OnInit } from '@angular/core';
import { FileService } from 'src/app/services/file.service';
import { ActivatedRoute, Router } from '@angular/router';
import { ProjectService } from 'src/app/services/project.service';
import { Loop } from 'src/app/models/loop';

@Component({
  selector: 'app-loops',
  templateUrl: './loops.component.html',
  styleUrls: ['./loops.component.css']
})
export class LoopsComponent implements OnInit {

  actualProject: number;
  diagram: string;
  isLoading: boolean;
  loops: Array<Loop>;
  highlightElements: Array<string>;

  constructor(private fileService: FileService, private projectService: ProjectService, private router: Router, private route: ActivatedRoute) {
    this.route.params.subscribe(params =>
      this.actualProject = params['projectId']
    )
  }

  async ngOnInit() {
    await this.initLoop();
    await this.loadBPMNDiagram();
  }

  highlight(loop: Loop) {
    this.highlightElements = [];
    this.highlightElements.push(loop.start);
    this.highlightElements.push(loop.follower);
    this.highlightElements.push(loop.end);
  }

  async initLoop() {
    this.isLoading = true;
    try {
      let result = await this.projectService.initLoop(this.actualProject);
      this.loops = result;
    } finally {
      this.isLoading = false;
    }
  }

  async loadBPMNDiagram() {
    this.isLoading = true;
    try {
      let result = await this.fileService.getBPMNDiagram(this.actualProject);
      this.diagram = result;
    } finally {
      this.isLoading = false;
    }
  }

  async initProject() {
    this.isLoading = true;
    try {
      let result = await this.projectService.initProject(this.actualProject);
      this.router.navigate(['/project', this.actualProject]);
    } finally {
      this.isLoading = false;
    }
  }
}
