import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';

import { FileService } from 'src/app/services/file.service';
import { ProjectService } from 'src/app/services/project.service';
import { SingleProjectConfig } from 'src/app/models/single-project-config';

@Component({
  selector: 'app-project',
  templateUrl: './project.component.html',
  styleUrls: ['./project.component.css']
})
export class ProjectComponent implements OnInit {

  actualProject: number;
  actualProjectConfig: SingleProjectConfig;
  diagram: string;
  isProjectLoading: boolean;
  isDiagramLoading: boolean;

  constructor(private fileService: FileService, private projectService: ProjectService, private route: ActivatedRoute) {
    this.route.params.subscribe(params =>
      this.actualProject = params['projectId']
    )
  }

  async ngOnInit() {
    await this.loadProject();
    await this.loadBPMNDiagram();
  }

  async loadProject() {
    this.isProjectLoading = true;
    try {
      let result = await this.projectService.getProject(this.actualProject);
      this.actualProjectConfig = result;
    } finally {
      this.isProjectLoading = false;
    }
  }

  async loadBPMNDiagram() {
    this.isDiagramLoading = true;
    try {
      let result = await this.fileService.getBPMNDiagram(this.actualProject);
      this.diagram = result;
    } finally {
      this.isDiagramLoading = false;
    }
  }
}
