import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';


import { FileService } from 'src/app/services/file.service';
import { ProjectService } from 'src/app/services/project.service';
import { SingleProjectConfig } from 'src/app/models/single-project-config';

import * as BpmnModdle from 'bpmn-moddle';
import { diff } from 'bpmn-js-differ';

@Component({
  selector: 'app-update-project',
  templateUrl: './update-project.component.html',
  styleUrls: ['./update-project.component.css']
})
export class UpdateProjectComponent implements OnInit {

  actualProject: number;
  actualProjectConfig: SingleProjectConfig;

  diagram: string;  // current BPMN-Model
  diagramNew: string; // updated BPMN-Model
  diagramsLoaded: boolean = false;

  constructor(private fileService: FileService, private projectService: ProjectService, private route: ActivatedRoute) {
    this.route.params.subscribe(params =>
      this.actualProject = params['projectId']
    )
  }

  async ngOnInit() {
    await this.loadProject();
    await this.loadDiagram();
    await this.loadDiagramUpdated();
  }

  compareProjects() {

    var diagram1 = new BpmnModdle().fromXML(this.diagram);
    var diagram2 = new BpmnModdle().fromXML(this.diagramNew);

    var changes = diff(diagram1, diagram2);
    console.log(changes._removed);
  }



  async loadProject() {
    try {
      let result = await this.projectService.getProject(this.actualProject);
      this.actualProjectConfig = result;
    } 
    catch(e) {
      console.log(e);
    }
  }

  async loadDiagram() {
    try {
      let result = await this.fileService.getBPMNDiagram(this.actualProject);
      this.diagram = result;
    }
    finally {
      this.diagramsLoaded = false;
    }
  }

  async loadDiagramUpdated() {
    try {
      let result = await this.fileService.getUpdatedBPMNDiagram(this.actualProject);
      this.diagramNew = result;
    }
    finally {
      this.diagramsLoaded = true;
    }

  }
}